@@ -1,13 +1,17 @@
 import logging
 import pathlib
-from typing import Union, Optional, List, Sequence, overload, BinaryIO
+import typing
+from copy import deepcopy
+from typing import Union, Optional, List, Sequence, overload, BinaryIO, Iterable
+
+import numpy as np
 
 from . import errors
 from .compression import LazBackend
 from .header import LasHeader
 from .laswriter import LasWriter
 from .point import record, dims, ExtraBytesParams, PointFormat
-from .point.dims import ScaledArrayView, OLD_LASPY_NAMES
+from .point.dims import ScaledArrayView, SubFieldView, OLD_LASPY_NAMES
 from .vlrs.vlrlist import VLRList
 
 logger = logging.getLogger(__name__)
@@ -29,60 +33,61 @@ class LasData:
     """
 
     def __init__(
-        self, header: LasHeader, points: Optional[record.PackedPointRecord] = None
+        self,
+        header: LasHeader,
+        points: Optional[
+            Union[record.PackedPointRecord, record.ScaleAwarePointRecord]
+        ] = None,
     ) -> None:
         if points is None:
-            points = record.PackedPointRecord.zeros(
-                header.point_count, header.point_format
+            points = record.ScaleAwarePointRecord.zeros(
+                header.point_count, header=header
             )
-        elif points.point_format != header.point_format:
+        if points.point_format != header.point_format:
             raise errors.LaspyException("Incompatible Point Formats")
+        if isinstance(points, record.PackedPointRecord):
+            points = record.ScaleAwarePointRecord(
+                points.array,
+                header.point_format,
+                scales=header.scales,
+                offsets=header.offsets,
+            )
+        else:
+            assert np.all(header.scales, points.scales)
+            assert np.all(header.offsets, points.offsets)
         self.__dict__["_points"] = points
-        self.points: record.PackedPointRecord
+        self.points: record.ScaleAwarePointRecord
         self.header: LasHeader = header
         if header.version.minor >= 4:
             self.evlrs: Optional[VLRList] = VLRList()
         else:
             self.evlrs: Optional[VLRList] = None
 
-    @property
-    def x(self) -> ScaledArrayView:
-        """Returns the scaled x positions of the points as doubles"""
-        return ScaledArrayView(self.X, self.header.x_scale, self.header.x_offset)
-
-    @x.setter
-    def x(self, value) -> None:
-        if len(value) > len(self.points):
-            self.points.resize(len(value))
-        self.x[:] = value
-
-    @property
-    def y(self) -> ScaledArrayView:
-        """Returns the scaled y positions of the points as doubles"""
-        return ScaledArrayView(self.Y, self.header.y_scale, self.header.y_offset)
-
-    @y.setter
-    def y(self, value) -> None:
-        if len(value) > len(self.points):
-            self.points.resize(len(value))
-        self.y[:] = value
-
-    @property
-    def z(self) -> ScaledArrayView:
-        """Returns the scaled z positions of the points as doubles"""
-        return ScaledArrayView(self.Z, self.header.z_scale, self.header.z_offset)
-
-    @z.setter
-    def z(self, value) -> None:
-        if len(value) > len(self.points):
-            self.points.resize(len(value))
-        self.z[:] = value
-
     @property
     def point_format(self) -> PointFormat:
         """Shortcut to get the point format"""
         return self.points.point_format
 
+    @property
+    def xyz(self) -> np.ndarray:
+        """Returns a **new** 2D numpy array with the x,y,z coordinates
+
+        >>> import laspy
+        >>> las = laspy.read("tests/data/simple.las")
+        >>> xyz = las.xyz
+        >>> xyz.ndim
+        2
+        >>> xyz.shape
+        (1065, 3)
+        >>> np.all(xyz[..., 0] == las.x)
+        True
+        """
+        return np.vstack((self.x, self.y, self.z)).transpose()
+
+    @xyz.setter
+    def xyz(self, value) -> None:
+        self.points[("x", "y", "z")] = value
+
     @property
     def points(self) -> record.PackedPointRecord:
         """Returns the point record"""
@@ -90,12 +95,14 @@ class LasData:
 
     @points.setter
     def points(self, new_points: record.PackedPointRecord) -> None:
-        if new_points.point_format != self._points.point_format:
+        if new_points.point_format != self.point_format:
             raise errors.IncompatibleDataFormat(
                 "Cannot set points with a different point format, convert first"
             )
         self._points = new_points
         self.update_header()
+        # make sure both point format point to the same object
+        self._points.point_format = self.header.point_format
 
     @property
     def vlrs(self) -> VLRList:
@@ -131,11 +138,68 @@ class LasData:
         params: list of parameters of the new extra dimensions to add
         """
         self.header.add_extra_dims(params)
-        new_point_record = record.PackedPointRecord.from_point_record(
-            self.points, self.header.point_format
+        new_point_record = record.ScaleAwarePointRecord.zeros(
+            len(self.points), header=self.header
         )
+        new_point_record.copy_fields_from(self.points)
         self.points = new_point_record
 
+    def remove_extra_dims(self, names: Iterable[str]) -> None:
+        """Remove multiple extra dimensions from this object
+
+        Parameters
+        ----------
+
+        names: iterable,
+            names of the extra dimensions to be removed
+
+
+        Raises
+        ------
+
+        LaspyException: if you try to remove an extra dimension that do not exist.
+
+        """
+        extra_dimension_names = list(self.point_format.extra_dimension_names)
+        not_extra_dimension = [
+            name for name in names if name not in extra_dimension_names
+        ]
+        if not_extra_dimension:
+            raise errors.LaspyException(
+                f"'{not_extra_dimension}' are not extra dimensions and cannot be removed"
+            )
+
+        self.header.remove_extra_dims(names)
+        new_point_record = record.ScaleAwarePointRecord.zeros(
+            len(self.points), header=self.header
+        )
+        new_point_record.copy_fields_from(self.points)
+        self.points = new_point_record
+
+    def remove_extra_dim(self, name: str) -> None:
+        """Remove an extra dimensions from this object
+
+        .. note::
+
+             If you plan on removing multiple extra dimensions,
+             prefer :meth:`.remove_extra_dims` as it will
+             save re-allocations and data copy
+
+         Parameters
+         ----------
+
+         name: str,
+             name of the extra dimension to be removed
+
+
+         Raises
+         ------
+
+         LaspyException: if you try to remove an extra dimension that do not exist.
+
+        """
+        self.remove_extra_dims([name])
+
     def update_header(self) -> None:
         """Update the information stored in the header
         to be in sync with the actual data.
@@ -228,12 +292,22 @@ class LasData:
                 writer.write_evlrs(self.evlrs)
 
     def change_scaling(self, scales=None, offsets=None) -> None:
-        if scales is None:
-            scales = self.header.scales
-        if offsets is None:
-            offsets = self.header.offsets
+        """This changes the scales and/or offset used for the x,y,z
+        dimensions.
 
-        record.apply_new_scaling(self, scales, offsets)
+        It recomputes the internal, non-scaled X,Y,Z dimensions
+        to match the new scales and offsets.
+
+        It also updates the header with the new values of scales and offsets.
+
+        Parameters
+        ----------
+        scales: optional
+                New scales to be used. If not provided, the scales won't change.
+        offsets: optional
+                 New offsets to be used. If not provided, the offsets won't change.
+        """
+        self.points.change_scaling(scales, offsets)
 
         self.header.scales = scales
         self.header.offsets = offsets
@@ -289,8 +363,28 @@ class LasData:
         else:
             super().__setattr__(key, value)
 
+    @typing.overload
+    def __getitem__(
+        self, item: Union[str, List[str]]
+    ) -> Union[np.ndarray, ScaledArrayView, SubFieldView]:
+        ...
+
+    @typing.overload
+    def __getitem__(self, item: Union[int, typing.Iterable[int], slice]) -> "LasData":
+        ...
+
     def __getitem__(self, item):
-        return self.points[item]
+        try:
+            item_is_list_of_str = all(isinstance(el, str) for el in iter(item))
+        except TypeError:
+            item_is_list_of_str = False
+
+        if isinstance(item, str) or item_is_list_of_str:
+            return self.points[item]
+        else:
+            las = LasData(deepcopy(self.header), points=self.points[item])
+            las.update_header()
+            return las
 
     def __setitem__(self, key, value):
         self.points[key] = value
