@@ -182,7 +182,7 @@ def test_coords_when_using_create_from_header(las):
 
 
 def test_slicing(las):
-    las.points = las.points[len(las.points) // 2 :]
+    las.points = las.points[len(las.points) // 2:]
 
 
 @pytest.mark.parametrize("do_compress", do_compression)
@@ -207,3 +207,122 @@ def test_point_record_setitem_scaled_view():
 def test_laspy_file_raises():
     with pytest.raises(laspy.errors.LaspyException):
         laspy.file.File("some path")
+
+
+def test_lasdata_setitem_xyz_with_2d_array():
+    las = laspy.read(simple_las)
+
+    xyz = np.ones(len(las), dtype='3f8')
+    xyz[..., 1] = 2.0
+    xyz[..., 2] = 3.0
+
+    las[['x', 'y', 'z']] = xyz
+
+    assert np.all(las.x == xyz[..., 0])
+    assert np.all(las.y == xyz[..., 1])
+    assert np.all(las.z == xyz[..., 2])
+
+
+def test_lasdata_setitem_xyz_with_structured_array():
+    las = laspy.read(simple_las)
+
+    xyz = np.ones(len(las), dtype=[('x', 'f8'), ('y', 'f8'), ('z', 'f8')])
+    xyz['y'] = 2.0
+    xyz['z'] = 3.0
+
+    las[['x', 'y', 'z']] = xyz
+
+    assert np.all(las.x == xyz['x'])
+    assert np.all(las.y == xyz['y'])
+    assert np.all(las.z == xyz['z'])
+
+
+def test_lasdata_setitem_one_dimension():
+    las = laspy.read(simple_las)
+
+    las[['x']] = np.ones(len(las), 'f8') * 17.0
+    assert np.all(las.x == 17.0)
+
+
+def test_lasdata_setitem_works_with_subfields():
+    las = laspy.read(simple_las)
+
+    new_values = np.ones(len(las), dtype=[('classification', 'u1'), ('return_number', 'u1')])
+    new_values['classification'] = 23
+    new_values['return_number'] = 2
+
+    las[['classification', 'return_number']] = new_values
+    assert np.all(las.classification == 23)
+    assert np.all(las.return_number == 2)
+
+
+def test_las_data_getitem_indices():
+    las = laspy.read(simple_las)
+    las.classification[:] = 0
+
+    indices = np.array([1, 2, 3, 4])
+    sliced_las = las[indices]
+    sliced_las.classification[:] = 1
+
+    assert np.all(sliced_las.classification == 1)
+    # We expect sliced_las to give us a copy,
+    # So original las is no modified
+    assert np.all(las.classification == 0)
+
+
+def test_las_data_getitem_slice():
+    las = laspy.read(simple_las)
+    las.classification[:] = 0
+
+    sliced_las = las[0:10]
+    sliced_las.classification[:] = 1
+
+    assert np.all(sliced_las.classification == 1)
+    # Slicing does not trigger, advanced indexing
+    # so the underlying array is not a copy
+    # https://numpy.org/doc/stable/reference/arrays.indexing.html
+    assert np.all(las.classification[:10] == 1)
+    assert np.all(las.classification[10:] == 0)
+
+
+def test_change_scaling():
+    """ Check our change scaling method.
+
+    We expect the scaled x,y,z not to change
+    while the unscaled (integers) X,Y,Z should change.
+    """
+    hdr = laspy.LasHeader()
+    hdr.offsets = np.array([0.0, 0.0, 0.0])
+    hdr.scales = np.array([1.0, 1.0, 1.0])
+
+    las = laspy.LasData(hdr)
+
+    las['x'] = np.array([1, 2, 3, 4])
+    las['y'] = np.array([1, 2, 3, 4])
+    las['z'] = np.array([1, 2, 3, 4])
+
+    assert np.all(las.x == [1, 2, 3, 4])
+    assert np.all(las.y == [1, 2, 3, 4])
+    assert np.all(las.z == [1, 2, 3, 4])
+
+    assert np.all(las.X == [1, 2, 3, 4])
+    assert np.all(las.Y == [1, 2, 3, 4])
+    assert np.all(las.Z == [1, 2, 3, 4])
+
+    las.change_scaling(scales=[0.5, 0.1, 0.01])
+    assert np.all(las.x == [1, 2, 3, 4])
+    assert np.all(las.y == [1, 2, 3, 4])
+    assert np.all(las.z == [1, 2, 3, 4])
+
+    assert np.all(las.X == [2, 4, 6, 8])
+    assert np.all(las.Y == [10, 20, 30, 40])
+    assert np.all(las.Z == [100, 200, 300, 400])
+
+    las.change_scaling(offsets=[1, 20, 30])
+    assert np.all(las.x == [1, 2, 3, 4])
+    assert np.all(las.y == [1, 2, 3, 4])
+    assert np.all(las.z == [1, 2, 3, 4])
+
+    assert np.all(las.X == [0, 2, 4, 6])
+    assert np.all(las.Y == [-190, -180, -170, -160])
+    assert np.all(las.Z == [-2900, -2800, -2700, -2600])
